diff --git a/pyglance/glance/report-concise.txt b/pyglance/glance/report-concise.txt
index 4a4809f1137a189d5a06f4ab9bbd47d53b931a81..0d42e6b12898ba6198fd77cc0ebec81874911415 100644
--- a/pyglance/glance/report-concise.txt
+++ b/pyglance/glance/report-concise.txt
@@ -34,7 +34,7 @@ Copyright (c) 2021 University of Wisconsin SSEC. All rights reserved.
         ## info on which comparison this was
 
         ## a header with where our report is
-        <h3>${report_dir}</h3>
+        <h3><a href="./${report_dir}/index.html">${report_dir}</a></h3>
 
         <p>
         ${len(passed_vars)} / ${len(passed_vars) + len(failed_vars)} variables passed comparison
@@ -59,7 +59,7 @@ Copyright (c) 2021 University of Wisconsin SSEC. All rights reserved.
                 % for varKey in sorted(failed_vars) :
                     <tr>
                         <td>
-                            <a href="./${varKey}/index.html">${varKey}</a>
+                            <a href="./${report_dir}/${varKey}/index.html">${varKey}</a>
                         </td>
                         <td>
                             ${var_stats[varKey]["Numerical Comparison Statistics"]["diff_outside_epsilon_count"]}
@@ -103,7 +103,7 @@ Copyright (c) 2021 University of Wisconsin SSEC. All rights reserved.
             <%
                 isFirst = False
             %>
-            <a href="./${varKey}/index.html">${varKey}</a>
+            <a href="./${report_dir}/${varKey}/index.html">${varKey}</a>
         % endfor
         </p>
diff --git a/pyglance/glance/compare.py b/pyglance/glance/compare.py
index 823f5d6eff0945dc3205fc038b778960ad20bf79..c769287874a7118aa810129b77f769db831763aa 100644
--- a/pyglance/glance/compare.py
+++ b/pyglance/glance/compare.py
@@ -1720,8 +1720,9 @@ def main():
 
         Note: If you provided one or two directory paths and those paths included more than one set of files
         that Glance is able to generate reports for, those reports will be placed in the output path in
-        separate temporarily directories. These directories are only labeled numerically and with the name of
-        the A file. In future we hope to have a summary report available for the run.
+        separate temporarily directories. These directories are labeled numerically and with the name of
+        the A file. A "summary.html" summary report for the run will be created in the top level output
+        directory when comparing files (when simply inspecting files no summary report will be created).
 
         If you would prefer to generate reports without images, use the --reportonly option. This option will
         generate the html report but omit the images. This may be significantly faster, depending on your system,